@@ -15,9 +15,11 @@ from xml.sax.saxutils import escape
 from qal.common.xml_utils import XML_Translation, xml_base_type_value, find_child_node, xml_get_text,\
     xml_set_cdata, xml_get_numeric, xml_get_boolean, xml_get_allowed_value, xml_find_non_text_child
 from qal.common.resources import Resources
-# TODO : This is a wee bit risky, this means that the schema will be dynamic dependent on what the server supports.
-# Good or Bad?
+
 from csv import list_dialects
+import os
+
+
 
 
 def sql_property_to_xml_type(_PropertyName):
@@ -36,6 +38,9 @@ class SQL_XML(XML_Translation):
 
     encoding = 'utf-8'
     _resources = None
+    base_path = None
+    """The base path of the document. Allows for relative paths within."""
+
 
     def __init__(self):
         '''
@@ -112,17 +117,17 @@ class SQL_XML(XML_Translation):
         self._add_child_type_restriction(_document, _parent_node, "condition_part", condition_part()) 
         self._add_child_type_restriction(_document, _parent_node, "tabular_expression_item", tabular_expression_item_types()) 
                     
-        self._add_child_array_of(_document, _parent_node, 'Array_Parameter_String', ['Parameter_String'])
-        self._add_child_array_of(_document, _parent_node, 'Array_Parameter_Constraint', ['Parameter_Constraint'])
-        self._add_child_array_of(_document, _parent_node, 'Array_Parameter_ColumnDefinition', ['Parameter_ColumnDefinition'])
-        self._add_child_array_of(_document, _parent_node, 'Array_Parameter_Source', ['Parameter_Source'])
-        self._add_child_array_of(_document, _parent_node, 'Array_Parameter_WHEN', ['Parameter_WHEN'])
-        self._add_child_array_of(_document, _parent_node, 'Array_Parameter_Identifier', ["Parameter_Identifier"])
+        self._add_child_array_of(_document, _parent_node, 'Array_ParameterString', ['ParameterString'])
+        self._add_child_array_of(_document, _parent_node, 'Array_ParameterConstraint', ['ParameterConstraint'])
+        self._add_child_array_of(_document, _parent_node, 'Array_ParameterColumndefinition', ['ParameterColumndefinition'])
+        self._add_child_array_of(_document, _parent_node, 'Array_ParameterSource', ['ParameterSource'])
+        self._add_child_array_of(_document, _parent_node, 'Array_ParameterWhen', ['ParameterWhen'])
+        self._add_child_array_of(_document, _parent_node, 'Array_ParameterIdentifier', ["ParameterIdentifier"])
         self._add_child_array_of(_document, _parent_node, 'Array_Statement', ["statement"])
-        self._add_child_array_of(_document, _parent_node, 'Array_Parameter_ORDER_BY_item', ["Parameter_ORDER_BY_item"])
-        self._add_child_array_of(_document, _parent_node, 'Array_Parameter_Condition', ["Parameter_Condition"])
-        self._add_child_array_of(_document, _parent_node, 'Array_Parameter_Field', ["Parameter_Field"])
-        self._add_child_array_of(_document, _parent_node, 'Array_Parameter_Assignment', ["Parameter_Assignment"])
+        self._add_child_array_of(_document, _parent_node, 'Array_ParameterOrderByItem', ["ParameterOrderByItem"])
+        self._add_child_array_of(_document, _parent_node, 'Array_ParameterCondition', ["ParameterCondition"])
+        self._add_child_array_of(_document, _parent_node, 'Array_ParameterField', ["ParameterField"])
+        self._add_child_array_of(_document, _parent_node, 'Array_ParameterAssignment', ["ParameterAssignment"])
         self._add_child_array_of(_document, _parent_node, 'Array_expression_item', expression_item_types())
         self._add_child_array_of(_document, _parent_node, 'Array_tabular_expression_item', tabular_expression_item_types())    
         self._add_child_array_of(_document, _parent_node, 'Array_list', '*')        
@@ -214,7 +219,7 @@ class SQL_XML(XML_Translation):
 
         _stripped_classname = self._strip_own(_classname)
         
-        # Check for base typesError in Verb_CREATE_INDEX, name is not set.
+        # Check for base typesError in VerbCreateIndex, name is not set.
         if _stripped_classname.lower() in  ['str', 'int', 'float', 'datetime']:
             return xml_base_type_value(_node, _stripped_classname) 
         
@@ -223,6 +228,7 @@ class SQL_XML(XML_Translation):
         
         if hasattr(_obj, 'as_sql'):
             _obj._parent = _parent
+            _obj._base_path = self.base_path
             self._debug_print("_parse_class_xml_node: Found matching Parameter class for " + _classname + " : " + _obj_name)
 
         elif isinstance(_obj, list):
@@ -268,7 +274,7 @@ class SQL_XML(XML_Translation):
                         else:
                             _curr_child = xml_find_non_text_child(_curr_node)
                             if (_curr_child):
-                                _obj.__dict__[_curr_itemkey] = self._parse_class_xml_node(_curr_child, currtype[0], _obj)  
+                                _obj.__dict__[_curr_itemkey] = self._parse_class_xml_node(_curr_node, currtype[0], _obj)
                
                   
         if self._resources and hasattr(_obj, 'resource_uuid') and _obj.resource_uuid != None and _obj.resource_uuid != '':
@@ -278,16 +284,20 @@ class SQL_XML(XML_Translation):
         self._get_up("_parse_class_xml_node")       
         return _obj
 
-    def xml_to_sql_structure(self, _xml = "", _node = None ):
+    def xml_to_sql_structure(self, _xml = "", _node = None, _base_path = None):
         """Translates an XML file into a class structure"""
         _node = self.get_root_node('statement', _xml, _node)
-        
+
+        if _base_path:
+            self.base_path = os.path.dirname(_base_path)
+
         _resources_node = find_child_node(_node, 'resources')
-        
+
+
         if _resources_node:  
             self._debug_print("xml_to_sql_structure: Found resources.")
             # Send XML here, since resources now uses lxml      
-            self._resources = Resources(_resources_xml= _resources_node.toxml())
+            self._resources = Resources(_resources_xml= _resources_node.toxml(), _base_path = _base_path)
         
         _verb = xml_find_non_text_child(_node)
         if (_verb == None):
@@ -325,7 +335,7 @@ class SQL_XML(XML_Translation):
             _object_node = _document.createElement(self.prefix_own + ':' + _object.__class__.__name__)
             _parent_node.appendChild(_object_node)                
             if hasattr(_object, "__dict__"):
-                for _curr_property_name, currProperty in _object.__dict__.items():
+                for _curr_property_name, currProperty in sorted(_object.__dict__.items()):
                     if not _curr_property_name.lower() in ['row_separator'] and not hasattr(currProperty, '__call__') and _curr_property_name[0:1] != '_':
                         # Create node for property
                         _curr_node = _document.createElement(self.prefix_own + ':' + _curr_property_name)
